Places package dependencies in pkgs_path.
download_packages(app_dir, pkgs_path, pkgs, repo, remotes, auth_user,
auth_token)Development app's directory, defaults to getwd().
Default location inside the app working directory to install package dependencies This defaults to pkgs_path = "bin"
Character vector of package dependencies. Remote development versions are supported via remotes. pkgs are downloaded into file.path(app_dir, pkgs_path) as Windows binary packages (.zip). If you build binary packages and store them there before calling create_app, they will be included as well.
Default repository to install CRAN package dependencies. Defaults to repo = "https://cran.rstudio.com".
Character vector of GitHub repository addresses in the format username/repo[/subdir][\@ref|#pull] for GitHub package dependencies.
Bitbucket username. It is recommended to create a read-only account for each app. Support for OAuth 2 and tokens is in the works.
To install from a private Github repo, generate a personal access token (PAT) in https://github.com/settings/tokens and supply to this argument. This is safer than using a password because you can easily delete a PAT without affecting any others.